#!perl

use strict;
use warnings;

use Test::More;



plan tests => 1;

use_ok('Dist::Zilla::PluginBundle::IDOPEREL');
diag("Testing Dist::Zilla::PluginBundle::IDOPEREL $Dist::Zilla::PluginBundle::IDOPEREL::VERSION, Perl $], $^X");
